﻿/*
 *  Copyright 2010 Angus Helm
 * 
 *  This file is part of Terrella.
 *
 *  Terrella is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 * 
 *  Terrella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Terrella.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;

using SdlDotNet.Core;
using SdlDotNet.Graphics;
using SdlDotNet.Input;

namespace Terrella
{
    public class Game
    {
    	private GameMode mode { get; set; }
    	private RenderContext renderContext { get; set; }
    	private EventContext eventContext { get; set;}
    	public FSResources Resources { get; private set; }
    	
        [STAThread]
        public static void Main()
        {
            Game app = new Game();
            app.Go();
        }

        public Game()
        {
        	this.Resources = new FSResources();
        	
        	// initialize video
            Video.SetVideoMode(1280, 720);
            Video.WindowCaption = "Terrella";
            this.renderContext = new RenderContext(this.Resources, Video.Screen);
            
            this.eventContext = new EventContext();
            this.eventContext.Render = this.renderContext;
            this.eventContext.GameMode = new GameModeContext(this);
            this.eventContext.Mouse = new MouseContext();
            
            // make a map
            TerrellaRandom.SetRandom(new Random());
            WorldMap.Map m = new WorldMap.WorldMapGenerator(Resources).getWorldMap();
            this.mode = new WorldMap.GameMode(m);
        }

        public void Go()
        {
            Events.Quit += new EventHandler<QuitEventArgs>(this.Quit);
            Events.Tick += new EventHandler<TickEventArgs>(this.Tick);
            Events.MouseButtonDown += new EventHandler<MouseButtonEventArgs>(this.MouseButtonDown);
            Events.KeyboardDown += new EventHandler<KeyboardEventArgs>(this.KeyboardDown);
            Events.Run();
        }
        
        private void MouseButtonDown(object sender, MouseButtonEventArgs e) {
        	this.mode.MouseDownEvent(this.GetEventContext(), e.Button);
        }
        
        private void KeyboardDown(object sender, KeyboardEventArgs e) {
        	this.mode.KeyDownEvent(this.GetEventContext(), e.Key);
        }

        private void Quit(object sender, QuitEventArgs e)
        {
        	Quit();
        }
        
        public void Quit() {
        	Events.QuitApplication();
        }
        
        private void Tick(object sender, TickEventArgs e)
        {
        	this.mode.Update(this.GetEventContext());
        	this.mode.Render(this.GetEventContext());
        }
        
        private EventContext GetEventContext() {
        	return this.eventContext;
        }
        
        public void SetGameMode(GameMode gm) {
        	this.mode = gm;
        }
    }
}
