﻿/* 
 *  Copyright 2010 Angus Helm
 * 
 *  This file is part of Terrella.
 *
 *  Terrella is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 * 
 *  Terrella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Terrella.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Drawing;
using System.Collections.Generic;
using SdlDotNet.Graphics;

namespace Terrella
{
	/// <summary>
	/// Description of RenderContext.
	/// </summary>
	public class RenderContext
	{
		private Surface surface {get; set;}
		private Dictionary<string, Surface> cachedSurfaces {get; set;}
		private FSResources Resources {get; set;}
		
		public RenderContext(FSResources r, Surface s)
		{
			this.Resources = r;
			this.surface = s;
			this.cachedSurfaces = new Dictionary<string, Surface>();
		}
		
		public int Width {
			get {
				return this.surface.Width;
			}
		}
		
		public int Height {
			get {
				return this.surface.Height;
			}
		}
		
		public int HalfWidth { 
			get {
				return this.Width / 2;
			}
		}
		
		public int HalfHeight {
			get {
				return this.Height / 2;
			}
		}
		
		public void BlitImage(string imgname, int x, int y) {
			Surface s = LoadSurface(imgname);
			int rx = x - (s.Width / 2);
			int ry = y - (s.Height / 2);
			this.surface.Blit(s, new Point(rx, ry));
		}
		
		public void Fill(Color c) {
			this.surface.Fill(c);
		}
		
		public void Update() {
			this.surface.Update();
		}
		
		private Surface LoadSurface(string imgname) {
			if (!cachedSurfaces.ContainsKey(imgname)) {
				string realpath = Resources.GetRealPath("Images." + imgname) + ".png";
				Surface s = new Surface(realpath);
				//s.Convert(this.surface, true, true);
				cachedSurfaces.Add(imgname, s);
			}
			return cachedSurfaces[imgname];
		}
	}
}
