﻿/*
 *  Copyright 2010 Angus Helm
 * 
 *  This file is part of Terrella.
 *
 *  Terrella is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 * 
 *  Terrella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Terrella.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using Terrella.WorldMap;
using SdlDotNet.Input;
using Terrella.WorldMap.AI;

namespace Terrella.UI.WorldMap
{
	/// <summary>
	/// Description of PlayerBrain.
	/// </summary>
	public class PlayerBrain : Brain
	{
		public Actor actor { get; set; }
		private double xtarget { get; set;}
		private double ytarget {get; set; }
		
		public PlayerBrain(Actor a) {
			actor = a;
			xtarget = actor.X + 250;
			ytarget = actor.Y;
		}
		
		public void Think() {
			double speed = 0.25;
			double distance = BrainUtils.GetDistanceBetweenPoints(actor.X, actor.Y, xtarget, ytarget);
			if (distance >= speed) {
				BrainUtils.MoveActorInDirection(actor,
				                                BrainUtils.DirectionToPoint(actor.X, actor.Y, xtarget, ytarget),
				                                speed);
			}
		}
		
		public void MouseDownEvent(Terrella.EventContext uc, MouseButton button) {
			// check for stuff on the ui
			// check for stuff on the map
			double realx = actor.X + (uc.Mouse.X - uc.Render.HalfWidth);
			double realy = actor.Y + (uc.Mouse.Y - uc.Render.HalfHeight);
			// check if clicked on sprite
			// else clicked on ground
			xtarget = realx;
			ytarget = realy;
		}
		
		public void KeyDownEvent(Terrella.EventContext ec, Key key) {
			if (key == Key.Escape) {
				ec.GameMode.Quit();
			}
		}
	}
}
