﻿/*
 *  Copyright 2010 Angus Helm
 * 
 *  This file is part of Terrella.
 *
 *  Terrella is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 * 
 *  Terrella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Terrella.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using SdlDotNet.Graphics;
using Terrella.UI.WorldMap;

namespace Terrella.WorldMap
{
	/// <summary>
	/// Description of GameMode.
	/// </summary>
	public class GameMode : Terrella.GameMode
	{
		private Map map { get; set; }
		private PlayerBrain playerBrain { get; set; }
		
		public GameMode(Map m)
		{
			map = m;
			
			map.Player.Brain.actor = null;
			playerBrain = new PlayerBrain(map.Player);
			map.Player.Brain = playerBrain;
		}
		
		public void Update(Terrella.EventContext uc) {
			foreach (Actor a in this.map.Actors) {
				a.Brain.Think();
			}
		}
		
		public void Render(Terrella.EventContext ec) {
			Terrella.RenderContext rc = ec.Render;
			rc.Fill(System.Drawing.Color.ForestGreen);
			
			foreach (Actor a in this.map.Actors) {
				double relx = a.X - this.map.Player.X;
				double rely = a.Y - this.map.Player.Y;
				
				relx = (rc.Width / 2) + relx;
				rely = (rc.Height / 2) + rely;
				
				rc.BlitImage("WorldMap.Actors." + a.RenderId + ".Stand", (int)relx, (int)rely);
			}
			
			rc.Update();
		}
		
		public void MouseDownEvent(Terrella.EventContext uc, SdlDotNet.Input.MouseButton button) {
			playerBrain.MouseDownEvent(uc, button);
		}
		
		public void KeyDownEvent(Terrella.EventContext ec, SdlDotNet.Input.Key key) {
			playerBrain.KeyDownEvent(ec, key);
		}
	}
}
